// @dart = 2.8

import 'dart:async';
import 'dart:io';

import '../base/common.dart';
import '../globals.dart';
import '../runner/faircli_command.dart';
import '../util/util.dart';

class ServerCommand extends FaircliCommand {
  ServerCommand() {
    argParser.addOption(
      'description',
      defaultsTo: 'Server',
      help: 'The description to start a local server for download fair patch.',
    );
  }

  @override
  final String name = 'server';

  @override
  final String description = 'Start a local server for download fair patch';

  @override
  Future<FaircliCommandResult> runCommand() async {
    var currentPath = localFileSystem.currentDirectory.path;
    var fileRoot = userRootPath();
    var toolDir = fs.path.join(fileRoot, 'FairServer', 'bin');
    var toolPath = fs.path.join(toolDir, 'server.dill');

    try {
      cliPrint('Start local fair server...');
      var runResult = await Process.run(
          'dart', ['run', toolPath, '-d', currentPath],
          workingDirectory: currentPath);
      if (runResult.exitCode != 0) {
        cliPrint('${runResult.stdout}');
        cliPrint('${runResult.stderr}');
        cliPrint('Start local server failed.');
      } else {
        cliPrint('Start local server succeed.');
      }
    } catch (e) {
      throwToolExit('Failed to start local server: $e');
    }
    return null;
  }
}
